OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Cancel",
    "Delete" : "Läschen",
    "Edit" : "Änneren",
    "Name" : "Numm",
    "Host" : "Host",
    "Enabled" : "Aktivéiert",
    "Add" : "Dobäisetzen",
    "Disabled" : "Deaktivéiert",
    "Confirm" : "Konfirméieren",
    "Save" : "Späicheren",
    "Report a bug" : "E Feeler melden",
    "Actions" : "Aktiounen",
    "Type" : "Typ",
    "Documentation" : "Dokumentatioun",
    "Details" : "Detailer",
    "Updates" : "Updates",
    "Disable" : "Ofschalten"
},
"nplurals=2; plural=(n != 1);");
